@@ -26,9 +26,9 @@ import asyncio
 
 _FALLBACKS = [
     "https://mystb.in",
+    "https://hastebin.com",
     "https://haste.unbelievaboat.com",
-    "https://paste.pythondiscord.com",    
-    "https://hastebin.com"
+    "https://paste.pythondiscord.com"
 ]
 #_HASTE_URLS_FOR_REGEX = '|'.join(_FALLBACKS[8:]).replace(".", "\\.")
 # _HASTE_URLS_RAW = "(https://|http://)?({})/(raw/)?(?P<key>.+)".format(_HASTE_URLS_FOR_REGEX)
